=============
API reference
=============

properties
==========

.. automodule:: input.properties
    :members:
    :undoc-members:

core
====

rows
----

.. automodule:: pyxml2pdf.core.rows
    :members:
    :private-members:
    :undoc-members:

events
------

.. automodule:: pyxml2pdf.core.events
    :members:
    :private-members:
    :undoc-members:

initializer
-----------

.. automodule:: pyxml2pdf.core.initializer
    :members:
    :private-members:
    :undoc-members:

parser
------

.. automodule:: pyxml2pdf.core.parser
    :members:
    :private-members:
    :undoc-members:

post_processor
--------------

.. automodule:: pyxml2pdf.core.post_processor
    :members:
    :private-members:
    :undoc-members:

sorter
------

.. automodule:: pyxml2pdf.core.sorter
    :members:
    :private-members:
    :undoc-members:

tables
======

tables
------

.. automodule:: pyxml2pdf.tables.tables
    :members:
    :private-members:

builder
-------

.. automodule:: pyxml2pdf.tables.builder
    :members:
    :private-members:
    :undoc-members:

styles
======

table_styles
------------

.. automodule:: pyxml2pdf.styles.table_styles
    :members:
    :private-members:
    :undoc-members:
